==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN päällä</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN pois</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock päällä</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock pois</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numeronäppäimet päällä</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numeronäppäimet pois</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Kosketuslevy päällä</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Kosketuslevy pois</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Kosketuslevy painike</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn-painike</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Lentotila päällä</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Lentotila pois</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Mykistys päällä</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Mykistys pois</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Tasapainoinen teho</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Virransäästö</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Korkea suoritusteho</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Ikkunatehosteet käytössä</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Ikkunatehosteet poistettu</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Ikkunatehosteiden käyttöönotto epäonnistui</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN päällä</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN pois</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock päällä</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock pois</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numeronäppäimet päällä</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numeronäppäimet pois</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Kosketuslevy päällä</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Kosketuslevy pois</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Kosketuslevy painike</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn-painike</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Lentotila päällä</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Lentotila pois</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Mykistys päällä</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Mykistys pois</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Tasapainoinen teho</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Virransäästö</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Korkea suoritusteho</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Ikkunatehosteet käytössä</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Ikkunatehosteet poistettu</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Ikkunatehosteiden käyttöönotto epäonnistui</translation>
    </message>
</context>
</TS>
